'''
Manage storage queues.
'''
from ... pyaz_utils import _call_az
from . import metadata, policy


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, fail_on_exist=None, metadata=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - fail_on_exist --  Specifies whether to throw an exception if the queue already exists.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage queue create", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, fail_not_exist=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - fail_not_exist --  Specifies whether to throw an exception if the queue doesn't exist.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage queue delete", locals())


def generate_sas(name, account_key=None, account_name=None, connection_string=None, expiry=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    

    Required Parameters:
    - name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes invalid. Do not use if a stored access policy is referenced with --id that specifies this value.
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - permissions -- The permissions the SAS grants. Allowed values: (a)dd (p)rocess (r)ead (u)pdate (a)dd (p)rocess (r)ead (u)pdate. Do not use if a stored access policy is referenced with --id that specifies this value. Can be combined.
    - policy_name -- The name of a stored access policy within the share's ACL.
    - start -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes valid. Do not use if a stored access policy is referenced with --id that specifies this value. Defaults to the time of the request.
    '''
    return _call_az("az storage queue generate-sas", locals())


def stats(account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage queue stats", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - name -- The queue name.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage queue exists", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, include_metadata=None, marker=None, num_results=None, prefix=None, sas_token=None, show_next_marker=None, timeout=None):
    '''
    List queues in a storage account.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - include_metadata -- Specify that queue metadata be returned in the response.
    - marker -- A string value that identifies the portion of the list of containers to be returned with the next listing operation. The operation returns the NextMarker value within the response body if the listing operation did not return all containers remaining to be listed with the current page. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - num_results -- Specify the maximum number to return. If the request does not specify num_results, or specifies a value greater than 5000, the server will return up to 5000 items. Note that if the listing operation crosses a partition boundary, then the service will return a continuation token for retrieving the remaining of the results. Provide "*" to return all.
    - prefix -- Filter the results to return only queues whose names begin with the specified prefix.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - show_next_marker -- Show nextMarker in result when specified.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage queue list", locals())




'''
Manage Azure Virtual Networks.
'''
from ... pyaz_utils import _call_az
from . import peering, subnet


def delete(name, resource_group):
    '''
    Delete a virtual network.

    Required Parameters:
    - name -- The virtual network (VNet) name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet delete", locals())


def list(resource_group=None):
    '''
    List virtual networks.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet list", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a virtual network.

    Required Parameters:
    - name -- The virtual network (VNet) name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network vnet show", locals())


def check_ip_address(ip_address, name, resource_group):
    '''
    Check if a private IP address is available for use within a virtual network.

    Required Parameters:
    - ip_address -- The private IP address to be verified.
    - name -- The virtual network (VNet) name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet check-ip-address", locals())


def create(name, resource_group, address_prefixes=None, bgp_community=None, ddos_protection=None, ddos_protection_plan=None, dns_servers=None, edge_zone=None, enable_encryption=None, encryption_enforcement_policy=None, flowtimeout=None, location=None, network_security_group=None, subnet_name=None, subnet_prefixes=None, tags=None, vm_protection=None):
    '''
    Create a virtual network.

    Required Parameters:
    - name -- The virtual network (VNet) name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - address_prefixes -- Space-separated list of IP address prefixes for the VNet.
    - bgp_community -- The BGP community associated with the virtual network.
    - ddos_protection -- Control whether DDoS protection is enabled.
    - ddos_protection_plan -- Name or ID of a DDoS protection plan to associate with the VNet.
    - dns_servers -- Space-separated list of DNS server IP addresses.
    - edge_zone -- The name of edge zone.
    - enable_encryption -- Enable encryption on the virtual network.
    - encryption_enforcement_policy -- To control if the Virtual Machine without encryption is allowed in encrypted Virtual Network or not.
    - flowtimeout -- The FlowTimeout value (in minutes) for the Virtual Network
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - network_security_group -- Name or ID of a network security group (NSG).
    - subnet_name -- Name of a new subnet to create within the VNet.
    - subnet_prefixes -- Space-separated list of address prefixes in CIDR format for the new subnet. If omitted, automatically reserves a /24 (or as large as available) block within the VNet address space.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vm_protection -- Enable VM protection for all subnets in the VNet.
    '''
    return _call_az("az network vnet create", locals())


def update(name, resource_group, add=None, address_prefixes=None, bgp_community=None, ddos_protection=None, ddos_protection_plan=None, dns_servers=None, enable_encryption=None, encryption_enforcement_policy=None, flowtimeout=None, force_string=None, remove=None, set=None, vm_protection=None):
    '''
    Update a virtual network.

    Required Parameters:
    - name -- The virtual network (VNet) name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - address_prefixes -- Space-separated list of IP address prefixes for the VNet.
    - bgp_community -- The BGP community associated with the virtual network.
    - ddos_protection -- Control whether DDoS protection is enabled.
    - ddos_protection_plan -- Name or ID of a DDoS protection plan to associate with the VNet.
    - dns_servers -- Space-separated list of DNS server IP addresses.
    - enable_encryption -- Enable encryption on the virtual network.
    - encryption_enforcement_policy -- To control if the Virtual Machine without encryption is allowed in encrypted Virtual Network or not.
    - flowtimeout -- The FlowTimeout value (in minutes) for the Virtual Network
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - vm_protection -- Enable VM protection for all subnets in the VNet.
    '''
    return _call_az("az network vnet update", locals())


def list_endpoint_services(location):
    '''
    List which services support VNET service tunneling in a given region.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network vnet list-endpoint-services", locals())


def list_available_ips(name, resource_group):
    '''
    List some available ips in the vnet.

    Required Parameters:
    - name -- The virtual network (VNet) name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet list-available-ips", locals())




from ..... pyaz_utils import _call_az

def add(connection_monitor, endpoint_dest_name, endpoint_source_name, location, name, test_config_name, disable=None, endpoint_dest_address=None, endpoint_dest_resource_id=None, endpoint_source_address=None, endpoint_source_resource_id=None, frequency=None, http_method=None, http_path=None, http_port=None, http_valid_status_codes=None, https_prefer=None, icmp_disable_trace_route=None, preferred_ip_version=None, protocol=None, tcp_disable_trace_route=None, tcp_port=None, threshold_failed_percent=None, threshold_round_trip_time=None):
    '''
    Add a test group along with new-added/existing endpoint and test configuration to a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - endpoint_dest_name -- The name of the destination of connection monitor endpoint. If you are creating a V2 Connection Monitor, it's required
    - endpoint_source_name -- The name of the source of connection monitor endpoint. If you are creating a V2 Connection Monitor, it's required
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor test group
    - test_config_name -- The name of the connection monitor test configuration. If you are creating a V2 Connection Monitor, it's required

    Optional Parameters:
    - disable -- Value indicating whether test group is disabled. false is default.
    - endpoint_dest_address -- Address of the destination of connection monitor endpoint (IP or domain name)
    - endpoint_dest_resource_id -- Resource ID of the destination of connection monitor endpoint
    - endpoint_source_address -- Address of the source of connection monitor endpoint (IP or domain name)
    - endpoint_source_resource_id -- Resource ID of the source of connection monitor endpoint. If endpoint is intended to used as source, this option is required.
    - frequency -- The frequency of test evaluation, in seconds
    - http_method -- The HTTP method to use
    - http_path -- The path component of the URI. For instance, "/dir1/dir2"
    - http_port -- The port to connect to
    - http_valid_status_codes -- Space-separated list of HTTP status codes to consider successful. For instance, "2xx 301-304 418"
    - https_prefer -- Value indicating whether HTTPS is preferred over HTTP in cases where the choice is not explicit
    - icmp_disable_trace_route -- Value indicating whether path evaluation with trace route should be disabled. false is default.
    - preferred_ip_version -- The preferred IP version to use in test evaluation. The connection monitor may choose to use a different version depending on other parameters
    - protocol -- The protocol to use in test evaluation
    - tcp_disable_trace_route -- Value indicating whether path evaluation with trace route should be disabled. false is default.
    - tcp_port -- The port to connect to
    - threshold_failed_percent -- The maximum percentage of failed checks permitted for a test to evaluate as successful
    - threshold_round_trip_time -- The maximum round-trip time in milliseconds permitted for a test to evaluate as successful
    '''
    return _call_az("az network watcher connection-monitor test-group add", locals())


def remove(connection_monitor, location, name):
    '''
    Remove test group from a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor test group
    '''
    return _call_az("az network watcher connection-monitor test-group remove", locals())


def show(connection_monitor, location, name):
    '''
    Show a test group of a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- The name of the connection monitor test group
    '''
    return _call_az("az network watcher connection-monitor test-group show", locals())


def list(connection_monitor, location):
    '''
    List all test groups of a connection monitor

    Required Parameters:
    - connection_monitor -- Connection monitor name.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network watcher connection-monitor test-group list", locals())




'''
Manage gallery sharing profile
'''
from ... pyaz_utils import _call_az

def add(gallery_name, resource_group, no_wait=None, op_type=None, subscription_ids=None, tenant_ids=None):
    '''
    Share gallery with subscriptions and tenants

    Required Parameters:
    - gallery_name -- The name of the Shared Image Gallery.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - op_type -- distinguish add operation and remove operation
    - subscription_ids -- A list of subscription ids to share the gallery.
    - tenant_ids -- A list of tenant ids to share the gallery.
    '''
    return _call_az("az sig share add", locals())


def remove(gallery_name, resource_group, no_wait=None, op_type=None, subscription_ids=None, tenant_ids=None):
    '''
    stop sharing gallery with a subscription or tenant

    Required Parameters:
    - gallery_name -- The name of the Shared Image Gallery.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - op_type -- distinguish add operation and remove operation
    - subscription_ids -- A list of subscription ids to share the gallery.
    - tenant_ids -- A list of tenant ids to share the gallery.
    '''
    return _call_az("az sig share remove", locals())


def reset(gallery_name, resource_group, no_wait=None):
    '''
    disable gallery from being shared with subscription or tenant

    Required Parameters:
    - gallery_name -- The name of the Shared Image Gallery.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sig share reset", locals())


def wait(gallery_name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of a shared gallery is met.

    Required Parameters:
    - gallery_name -- gallery name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sig share wait", locals())




'''
Manage revisions for key-values stored in an App Configuration.
'''
from ... pyaz_utils import _call_az

def list(all=None, auth_mode=None, connection_string=None, datetime=None, endpoint=None, fields=None, key=None, label=None, name=None, top=None):
    '''
    Lists revision history of key-values.

    Optional Parameters:
    - all -- List all items.
    - auth_mode -- This parameter can be used for indicating how a data operation is to be authorized. If the auth mode is "key", provide connection string or store name and your account access keys will be retrieved for authorization. If the auth mode is "login", provide the store endpoint or store name and your "az login" credentials will be used for authorization. You can configure the default auth mode using `az configure --defaults appconfig_auth_mode=<auth_mode>`. For more information, see https://docs.microsoft.com/azure/azure-app-configuration/concept-enable-rbac
    - connection_string -- Combination of access key and endpoint of App Configuration. Can be found using 'az appconfig credential list'. Users can preset it using `az configure --defaults appconfig_connection_string=<connection_string>` or environment variable with the name AZURE_APPCONFIG_CONNECTION_STRING.
    - datetime -- Format: "YYYY-MM-DDThh:mm:ssZ". If no time zone specified, use UTC by default.
    - endpoint -- If auth mode is "login", provide endpoint URL of the App Configuration. The endpoint can be retrieved using "az appconfig show" command. You can configure the default endpoint using `az configure --defaults appconfig_endpoint=<endpoint>`
    - fields -- Space-separated customized output fields.
    - key -- If no key specified, return all keys by default. Support star sign as filters, for instance abc* means keys with abc as prefix.
    - label -- If no label specified, list all labels. Support star sign as filters, for instance abc* means labels with abc as prefix. Use '\0' for null label.
    - name -- Name of the App Configuration. You can configure the default name using `az configure --defaults app_configuration_store=<name>`
    - top -- Maximum number of items to return. Must be a positive integer. Default to 100.
    '''
    return _call_az("az appconfig revision list", locals())




'''
Manage throughput of Gremlin graph under an Azure Cosmos DB account.
'''
from ..... pyaz_utils import _call_az

def show(account_name, database_name, name, resource_group):
    '''
    Get the throughput of the Gremlin graph under an Azure Cosmos DB Gremlin database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Graph name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb gremlin graph throughput show", locals())


def update(account_name, database_name, name, resource_group, max_throughput=None, throughput=None):
    '''
    Update the throughput of the Gremlin graph under an Azure Cosmos DB Gremlin database.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Graph name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - max_throughput -- The maximum throughput resource can scale to (RU/s). Provided when the resource is autoscale enabled. The minimum value can be 4000 (RU/s)
    - throughput -- The throughput Gremlin graph (RU/s).
    '''
    return _call_az("az cosmosdb gremlin graph throughput update", locals())


def migrate(account_name, database_name, name, resource_group, throughput_type):
    '''
    Migrate the throughput of the Gremlin Graph between autoscale and manually provisioned.

    Required Parameters:
    - account_name -- Cosmosdb account name.
    - database_name -- Database name.
    - name -- Graph name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - throughput_type -- The type of throughput to migrate to.
    '''
    return _call_az("az cosmosdb gremlin graph throughput migrate", locals())




'''
Manage MySQL server keys.
'''
from .... pyaz_utils import _call_az

def create(kid, name, resource_group):
    '''
    Create server key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server key create", locals())


def delete(kid, name, resource_group, yes=None):
    '''
    Delete server key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql server key delete", locals())


def show(kid, name, resource_group):
    '''
    Show server key.

    Required Parameters:
    - kid -- The Azure Key Vault key identifier of the server key. An example key identifier is "https://YourVaultName.vault.azure.net/keys/YourKeyName/01234567890123456789012345678901"
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server key show", locals())


def list(name, resource_group):
    '''
    

    Required Parameters:
    - name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az mysql server key list", locals())




from .... pyaz_utils import _call_az

def create(application, cluster_name, metric_name, name, resource_group, default_load=None, primary_default_load=None, secondary_default_load=None, weight=None):
    '''
    Create a new managed service load metric on an Azure Service Fabric managed cluster.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - metric_name -- Specify the name of the metric.
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - default_load -- Specify the default amount of load, as a number, that this service creates for this metric. Used only for Stateless services.
    - primary_default_load -- Specify the default amount of load, as a number, that this service creates for this metric when it is a Primary replica. Used only for Stateful services.
    - secondary_default_load -- Specify the default amount of load, as a number, that this service creates for this metric when it is a Secondary replica. Used only for Stateful services.
    - weight -- Specify the service load metric relative weight, compared to other metrics configured for this service, as a number.
    '''
    return _call_az("az sf managed-service load-metrics create", locals())


def update(application, cluster_name, metric_name, name, resource_group, default_load=None, primary_default_load=None, secondary_default_load=None, weight=None):
    '''
    Update a managed service.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - metric_name -- Specify the name of the metric.
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - default_load -- Specify the default amount of load, as a number, that this service creates for this metric. Used only for Stateless services.
    - primary_default_load -- Specify the default amount of load, as a number, that this service creates for this metric when it is a Primary replica. Used only for Stateful services.
    - secondary_default_load -- Specify the default amount of load, as a number, that this service creates for this metric when it is a Secondary replica. Used only for Stateful services.
    - weight -- Specify the service load metric relative weight, compared to other metrics configured for this service, as a number.
    '''
    return _call_az("az sf managed-service load-metrics update", locals())


def delete(application, cluster_name, metric_name, name, resource_group):
    '''
    Delete a managed service.

    Required Parameters:
    - application -- Specify the name of the service.
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - metric_name -- Specify the name of the metric.
    - name -- Specify the name of the service.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-service load-metrics delete", locals())




'''
Manage web app snapshots.
'''
from .... pyaz_utils import _call_az

def list(name, resource_group, slot=None):
    '''
    List the restorable snapshots for a web app.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- The name of the slot.
    '''
    return _call_az("az webapp config snapshot list", locals())


def restore(name, resource_group, time, restore_content_only=None, slot=None, source_name=None, source_resource_group=None, source_slot=None):
    '''
    Restore a web app snapshot.

    Required Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - time -- Timestamp of the snapshot to restore.

    Optional Parameters:
    - restore_content_only -- Restore the web app files without restoring the settings.
    - slot -- The name of the slot.
    - source_name -- Name of the web app to retrieve snapshot from.
    - source_resource_group -- Name of the resource group to retrieve snapshot from.
    - source_slot -- Name of the web app slot to retrieve snapshot from.
    '''
    return _call_az("az webapp config snapshot restore", locals())




'''
Manage Azure NetApp Files (ANF) Volume replication operations.
'''
from .... pyaz_utils import _call_az

def approve(account_name, pool_name, resource_group, volume_name, remote_volume_resource_id=None):
    '''
    Authorize a volume as a replication destination for a specified source.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - remote_volume_resource_id -- The id of the destination replication volume
    '''
    return _call_az("az netappfiles volume replication approve", locals())


def suspend(account_name, pool_name, resource_group, volume_name, force=None):
    '''
    Suspend/break a volume replication for the specified destination volume. The replication process is suspended until resumed or deleted.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.

    Optional Parameters:
    - force -- None
    '''
    return _call_az("az netappfiles volume replication suspend", locals())


def resume(account_name, pool_name, resource_group, volume_name):
    '''
    Resync a volume replication for the specified destination volume. The replication process is resumed from source to destination.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume replication resume", locals())


def remove(account_name, pool_name, resource_group, volume_name):
    '''
    Delete a volume replication for the specified destination volume. The data replication objects of source and destination volumes will be removed.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume replication remove", locals())


def status(account_name, pool_name, resource_group, volume_name):
    '''
    Get the replication status for the specified replication volume.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume replication status", locals())


def re_initialize(account_name, pool_name, resource_group, volume_name):
    '''
    Re-initialise a volume replication for the specified destination volume. The replication process is resumed from source to destination.

    Required Parameters:
    - account_name -- Name of the ANF account.
    - pool_name -- Name of the ANF pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - volume_name -- Name of the ANF volume.
    '''
    return _call_az("az netappfiles volume replication re-initialize", locals())




'''
Get policy metadata resources.
'''
from ... pyaz_utils import _call_az

def list(top=None):
    '''
    List policy metadata resources.

    Optional Parameters:
    - top -- Maximum number of records to return.
    '''
    return _call_az("az policy metadata list", locals())


def show(name):
    '''
    Get a single policy metadata resource.

    Required Parameters:
    - name -- The name of the metadata resource.
    '''
    return _call_az("az policy metadata show", locals())




'''
Manage webhooks for Azure Container Registries.
'''
from ... pyaz_utils import _call_az

def list(registry, resource_group=None):
    '''
    List all of the webhooks for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr webhook list", locals())


def create(actions, name, registry, uri, headers=None, location=None, resource_group=None, scope=None, status=None, tags=None):
    '''
    Create a webhook for an Azure Container Registry.

    Required Parameters:
    - actions -- Space-separated list of actions that trigger the webhook to post notifications.
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - uri -- The service URI for the webhook to post notifications.

    Optional Parameters:
    - headers -- Space-separated custom headers in 'key[=value]' format that will be added to the webhook notifications. Use '' to clear existing headers.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope -- The scope of repositories where the event can be triggered. For example, 'foo:*' means events for all tags under repository 'foo'. 'foo:bar' means events for 'foo:bar' only. 'foo' is equivalent to 'foo:latest'. Empty means events for all repositories.
    - status -- Indicates whether the webhook is enabled.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az acr webhook create", locals())


def delete(name, registry, resource_group=None):
    '''
    Delete a webhook from an Azure Container Registry.

    Required Parameters:
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr webhook delete", locals())


def show(name, registry, resource_group=None):
    '''
    Get the details of a webhook.

    Required Parameters:
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr webhook show", locals())


def get_config(name, registry, resource_group=None):
    '''
    Get the service URI and custom headers for the webhook.

    Required Parameters:
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr webhook get-config", locals())


def list_events(name, registry, resource_group=None):
    '''
    List recent events for a webhook.

    Required Parameters:
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr webhook list-events", locals())


def ping(name, registry, resource_group=None):
    '''
    Trigger a ping event for a webhook.

    Required Parameters:
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr webhook ping", locals())


def update(name, registry, actions=None, add=None, force_string=None, headers=None, remove=None, resource_group=None, scope=None, set=None, status=None, tags=None, uri=None):
    '''
    Update a webhook.

    Required Parameters:
    - name -- The name of the webhook
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - actions -- Space-separated list of actions that trigger the webhook to post notifications.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - headers -- Space-separated custom headers in 'key[=value]' format that will be added to the webhook notifications. Use '' to clear existing headers.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - scope -- The scope of repositories where the event can be triggered. For example, 'foo:*' means events for all tags under repository 'foo'. 'foo:bar' means events for 'foo:bar' only. 'foo' is equivalent to 'foo:latest'. Empty means events for all repositories.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - status -- Indicates whether the webhook is enabled.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - uri -- The service URI for the webhook to post notifications.
    '''
    return _call_az("az acr webhook update", locals())




from ..... pyaz_utils import _call_az

def list(policy_name, resource_group):
    '''
    List properties of a web application firewall global configuration.

    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway waf-policy policy-setting list", locals())


def update(policy_name, resource_group, add=None, file_upload_limit_in_mb=None, force_string=None, max_request_body_size_in_kb=None, mode=None, remove=None, request_body_check=None, set=None, state=None):
    '''
    Update properties of a web application firewall global configuration.

    Required Parameters:
    - policy_name -- The name of the web application firewall policy.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - file_upload_limit_in_mb -- Maximum file upload size in Mb for WAF."
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - max_request_body_size_in_kb -- Maximum request body size in Kb for WAF.
    - mode -- Describes if it is in detection mode or prevention mode at policy level.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - request_body_check -- Specified to require WAF to check request Body.
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - state -- Describes if the policy is in enabled state or disabled state.
    '''
    return _call_az("az network application-gateway waf-policy policy-setting update", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    Get all reservation orders
    '''
    return _call_az("az reservations reservation-order list", locals())


def show(reservation_order_id, expand=None):
    '''
    Get a specific reservation order.

    Required Parameters:
    - reservation_order_id -- Order Id of the reservation

    Optional Parameters:
    - expand -- May be used to expand the planInformation.
    '''
    return _call_az("az reservations reservation-order show", locals())


def calculate(applied_scope_type, billing_scope, display_name, quantity, reserved_resource_type, sku, term, applied_scope=None, billing_plan=None, instance_flexibility=None, location=None, renew=None):
    '''
    Calculate price for a reservation order.

    Required Parameters:
    - applied_scope_type -- Type of the Applied Scope to update the reservation with
    - billing_scope -- Subscription that will be charged for purchasing Reservation.
    - display_name -- Friendly name for user to easily identified the reservation.
    - quantity -- Quantity of product for calculating price or purchasing.
    - reserved_resource_type -- Type of the resource for which the skus should be provided.
    - sku -- Sku name, get the sku list by using command az reservations catalog show
    - term -- Available reservation terms for this resource.

    Optional Parameters:
    - applied_scope -- Subscription that the benefit will be applied. Required if --applied-scope-type is Single. Do not specify if --applied-scope-type is Shared.
    - billing_plan -- The billing plan options available for this SKU.
    - instance_flexibility -- Type of the Instance Flexibility to update the reservation with.
    - location -- Values from: `az account list-locations`.
    - renew -- Set this to true will automatically purchase a new reservation on the expiration date time.
    '''
    return _call_az("az reservations reservation-order calculate", locals())


def purchase(applied_scope_type, billing_scope, display_name, quantity, reservation_order_id, reserved_resource_type, sku, term, applied_scope=None, billing_plan=None, instance_flexibility=None, location=None, renew=None):
    '''
    Purchase reservation order

    Required Parameters:
    - applied_scope_type -- Type of the Applied Scope to update the reservation with
    - billing_scope -- Subscription that will be charged for purchasing Reservation.
    - display_name -- Friendly name for user to easily identified the reservation.
    - quantity -- Quantity of product for calculating price or purchasing.
    - reservation_order_id -- Id of reservation order to purchase, generate by `az reservations reservation-order calculate`.
    - reserved_resource_type -- Type of the resource for which the skus should be provided.
    - sku -- Sku name, get the sku list by using command az reservations catalog show
    - term -- Available reservation terms for this resource.

    Optional Parameters:
    - applied_scope -- Subscription that the benefit will be applied. Required if --applied-scope-type is Single. Do not specify if --applied-scope-type is Shared.
    - billing_plan -- The billing plan options available for this SKU.
    - instance_flexibility -- Type of the Instance Flexibility to update the reservation with.
    - location -- Values from: `az account list-locations`.
    - renew -- Set this to true will automatically purchase a new reservation on the expiration date time.
    '''
    return _call_az("az reservations reservation-order purchase", locals())




'''
Manage container-based continuous deployment.
'''
from .... pyaz_utils import _call_az

def config(enable_cd, name, resource_group, slot=None):
    '''
    Configure continuous deployment via containers.

    Required Parameters:
    - enable_cd -- enable/disable continuous deployment
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment container config", locals())


def show_cd_url(name, resource_group, slot=None):
    '''
    Get the URL which can be used to configure webhooks for continuous deployment.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp deployment container show-cd-url", locals())




from .... pyaz_utils import _call_az

def add(certificate_store, certificate_url, cluster_name, resource_group, source_vault_id):
    '''
    Add a secret to the node type.

    Required Parameters:
    - certificate_store -- Specifies the certificate store on the Virtual Machine to which the certificate should be added. The specified certificate store is implicitly in the LocalMachine account.
    - certificate_url -- This is the URL of a certificate that has been uploaded to Key Vault as a secret. For adding a secret to the Key Vault, see [Add a key or secret to the key vault](https://docs.microsoft.com/azure/key-vault/key-vault-get-started/#add). In this case, your certificate needs to be It is the Base64 encoding of the following JSON Object which is encoded in UTF-8: <br><br> {<br>  "data":"<Base64-encoded-certificate>",<br>  "dataType":"pfx",<br>  "password":"<pfx-file-password>"<br>}/
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - source_vault_id -- Key Vault resource id containing the certificates.
    '''
    return _call_az("az sf managed-node-type vm-secret add", locals())




from .... pyaz_utils import _call_az
from . import address_pool, inbound_nat_rule


def create(name, nic_name, resource_group, app_gateway_address_pools=None, application_security_groups=None, gateway_name=None, lb_address_pools=None, lb_inbound_nat_rules=None, lb_name=None, make_primary=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, subnet=None, vnet_name=None):
    '''
    Create an IP configuration.

    Required Parameters:
    - name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - app_gateway_address_pools -- Space-separated list of names or IDs of application gateway backend address pools to associate with the NIC. If names are used, --gateway-name must be specified.
    - application_security_groups -- Space-separated list of application security groups.
    - gateway_name -- The name of the application gateway to use when adding address pools by name (ignored when IDs are specified).
    - lb_address_pools -- Space-separated list of names or IDs of load balancer address pools to associate with the NIC. If names are used, --lb-name must be specified.
    - lb_inbound_nat_rules -- Space-separated list of names or IDs of load balancer inbound NAT rules to associate with the NIC. If names are used, --lb-name must be specified.
    - lb_name -- The name of the load balancer to use when adding NAT rules or address pools by name (ignored when IDs are specified).
    - make_primary -- Set to make this configuration the primary one for the NIC.
    - private_ip_address -- Static IP address to use or ""('""' in PowerShell) to use a dynamic address.
    - private_ip_address_version -- None
    - public_ip_address -- Name or ID of the public IP to use.
    - subnet -- Name or ID of an existing subnet. If name is specified, also specify --vnet-name.
    - vnet_name -- The virtual network (VNet) associated with the subnet (Omit if supplying a subnet id).
    '''
    return _call_az("az network nic ip-config create", locals())


def update(name, nic_name, resource_group, add=None, app_gateway_address_pools=None, application_security_groups=None, force_string=None, gateway_lb=None, gateway_name=None, lb_address_pools=None, lb_inbound_nat_rules=None, lb_name=None, make_primary=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, remove=None, set=None, subnet=None, vnet_name=None):
    '''
    Update an IP configuration.

    Required Parameters:
    - name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - app_gateway_address_pools -- Space-separated list of names or IDs of application gateway backend address pools to associate with the NIC. If names are used, --gateway-name must be specified.
    - application_security_groups -- Space-separated list of application security groups.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - gateway_lb -- The reference to gateway load balancer frontend IP. If you want to delete it, input '""'(Powershell) or ""(Linux)
    - gateway_name -- The name of the application gateway to use when adding address pools by name (ignored when IDs are specified).
    - lb_address_pools -- Space-separated list of names or IDs of load balancer address pools to associate with the NIC. If names are used, --lb-name must be specified.
    - lb_inbound_nat_rules -- Space-separated list of names or IDs of load balancer inbound NAT rules to associate with the NIC. If names are used, --lb-name must be specified.
    - lb_name -- The name of the load balancer to use when adding NAT rules or address pools by name (ignored when IDs are specified).
    - make_primary -- Set to make this configuration the primary one for the NIC.
    - private_ip_address -- Static IP address to use or ""('""' in PowerShell) to use a dynamic address.
    - private_ip_address_version -- None
    - public_ip_address -- Name or ID of the public IP to use.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - subnet -- Name or ID of an existing subnet. If name is specified, also specify --vnet-name.
    - vnet_name -- The virtual network (VNet) associated with the subnet (Omit if supplying a subnet id).
    '''
    return _call_az("az network nic ip-config update", locals())


def list(nic_name, resource_group):
    '''
    List the IP configurations of a NIC.

    Required Parameters:
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nic ip-config list", locals())


def show(name, nic_name, resource_group):
    '''
    Show the details of an IP configuration.

    Required Parameters:
    - name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nic ip-config show", locals())


def delete(name, nic_name, resource_group):
    '''
    Delete an IP configuration.

    Required Parameters:
    - name -- The name of the IP configuration.
    - nic_name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nic ip-config delete", locals())




'''
Manage resource policy definitions.
'''
from ... pyaz_utils import _call_az

def create(name, description=None, display_name=None, management_group=None, metadata=None, mode=None, params=None, rules=None, subscription=None):
    '''
    Create a policy definition.

    Required Parameters:
    - name -- Name of the new policy definition.

    Optional Parameters:
    - description -- Description of policy definition.
    - display_name -- Display name of policy definition.
    - management_group -- The name of the management group of the policy [set] definition.
    - metadata -- Metadata in space-separated key=value pairs.
    - mode -- Mode of the policy definition, e.g. All, Indexed. Please visit https://aka.ms/azure-policy-mode for more information.
    - params -- JSON formatted string or a path to a file or uri with parameter definitions.
    - rules -- JSON formatted string or a path to a file with such content
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy definition create", locals())


def delete(name, management_group=None, subscription=None):
    '''
    Delete a policy definition.

    Required Parameters:
    - name -- The policy definition name.

    Optional Parameters:
    - management_group -- The name of the management group of the policy [set] definition.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy definition delete", locals())


def list(management_group=None, subscription=None):
    '''
    List policy definitions.

    Optional Parameters:
    - management_group -- The name of the management group of the policy [set] definition.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy definition list", locals())


def show(name, management_group=None, subscription=None):
    '''
    Show a policy definition.

    Required Parameters:
    - name -- The policy definition name.

    Optional Parameters:
    - management_group -- The name of the management group of the policy [set] definition.
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy definition show", locals())


def update(name, description=None, display_name=None, management_group=None, metadata=None, mode=None, params=None, rules=None, subscription=None):
    '''
    Update a policy definition.

    Required Parameters:
    - name -- The policy definition name.

    Optional Parameters:
    - description -- Description of policy definition.
    - display_name -- Display name of policy definition.
    - management_group -- The name of the management group of the policy [set] definition.
    - metadata -- Metadata in space-separated key=value pairs.
    - mode -- Mode of the policy definition, e.g. All, Indexed. Please visit https://aka.ms/azure-policy-mode for more information.
    - params -- JSON formatted string or a path to a file or uri with parameter definitions.
    - rules -- JSON formatted string or a path to a file with such content
    - subscription -- The subscription id of the policy [set] definition.
    '''
    return _call_az("az policy definition update", locals())




'''
Bicep CLI command group.
'''
from .. pyaz_utils import _call_az

def install(target_platform=None, version=None):
    '''
    Install Bicep CLI.

    Optional Parameters:
    - target_platform -- The platform the Bicep CLI will be running on. Set this to skip automatic platform detection if it does not work properly.
    - version -- The version of Bicep CLI to be installed. Default to the latest if not specified.
    '''
    return _call_az("az bicep install", locals())


def uninstall():
    '''
    Uninstall Bicep CLI.
    '''
    return _call_az("az bicep uninstall", locals())


def upgrade(target_platform=None):
    '''
    Upgrade Bicep CLI to the latest version.

    Optional Parameters:
    - target_platform -- The platform the Bicep CLI will be running on. Set this to skip automatic platform detection if it does not work properly.
    '''
    return _call_az("az bicep upgrade", locals())


def build(file, outdir=None, outfile=None, stdout=None):
    '''
    Build a Bicep file.

    Required Parameters:
    - file -- The path to the Bicep file to build in the file system.

    Optional Parameters:
    - outdir -- When set, saves the output at the specified directory.
    - outfile -- When set, saves the output as the specified file path.
    - stdout -- When set, prints all output to stdout instead of corresponding files.
    '''
    return _call_az("az bicep build", locals())


def decompile(file):
    '''
    Attempt to decompile an ARM template file to a Bicep file.

    Required Parameters:
    - file -- The path to the ARM template to decompile in the file system.
    '''
    return _call_az("az bicep decompile", locals())


def publish(file, target):
    '''
    Publish a bicep file to a remote module registry.

    Required Parameters:
    - file -- The path to the Bicep module file to publish in the file system.
    - target -- The target location where the Bicep module will be published.
    '''
    return _call_az("az bicep publish", locals())


def version():
    '''
    Show the installed version of Bicep CLI.
    '''
    return _call_az("az bicep version", locals())


def list_versions():
    '''
    List out all available versions of Bicep CLI.
    '''
    return _call_az("az bicep list-versions", locals())




'''
Manage the registration assignments in Azure.
'''
from ... pyaz_utils import _call_az

def create(definition, assignment_id=None, resource_group=None):
    '''
    Creates a new registration assignment.

    Required Parameters:
    - definition -- None

    Optional Parameters:
    - assignment_id -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managedservices assignment create", locals())


def show(assignment, include_definition=None, resource_group=None):
    '''
    Gets a registration assignment.

    Required Parameters:
    - assignment -- The identifier (guid) or the fully qualified resource id of the registration assignment. When resource id is used, subscription id and resource group parameters are ignored.

    Optional Parameters:
    - include_definition -- When provided, gets the associated registration definition details.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managedservices assignment show", locals())


def delete(assignment, resource_group=None):
    '''
    Deletes the registration assignment.

    Required Parameters:
    - assignment -- The identifier (guid) or the fully qualified resource id of the registration assignment. When resource id is used, subscription id and resource group parameters are ignored.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managedservices assignment delete", locals())


def list(include_definition=None, resource_group=None):
    '''
    List all the registration assignments.

    Optional Parameters:
    - include_definition -- When provided, gets the associated registration definition details.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az managedservices assignment list", locals())




'''
Manage Azure Cognitive Services accounts.
'''
from ... pyaz_utils import _call_az
from . import commitment_plan, deployment, identity, keys, network_rule


def create(kind, location, name, resource_group, sku, api_properties=None, assign_identity=None, custom_domain=None, encryption=None, storage=None, tags=None, yes=None):
    '''
    Manage Azure Cognitive Services accounts.

    Required Parameters:
    - kind -- the API name of cognitive services account
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- Name of the Sku of cognitive services account

    Optional Parameters:
    - api_properties -- Api properties in JSON format or a=b c=d format. Some cognitive services (i.e. QnA Maker) require extra api properties to create the account.
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this account.
    - custom_domain -- User domain assigned to the account. Name is the CNAME source.
    - encryption -- The encryption properties for this resource, in JSON format.
    - storage -- The storage accounts for this resource, in JSON array format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - yes -- Do not prompt for terms confirmation
    '''
    return _call_az("az cognitiveservices account create", locals())


def delete(name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account delete", locals())


def show(name, resource_group):
    '''
    Manage Azure Cognitive Services accounts.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account show", locals())


def update(name, resource_group, api_properties=None, custom_domain=None, encryption=None, sku=None, storage=None, tags=None):
    '''
    Manage Azure Cognitive Services accounts.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - api_properties -- Api properties in JSON format or a=b c=d format. Some cognitive services (i.e. QnA Maker) require extra api properties to create the account.
    - custom_domain -- User domain assigned to the account. Name is the CNAME source.
    - encryption -- The encryption properties for this resource, in JSON format.
    - sku -- Name of the Sku of cognitive services account
    - storage -- The storage accounts for this resource, in JSON array format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az cognitiveservices account update", locals())


def list(resource_group=None):
    '''
    Manage Azure Cognitive Services accounts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account list", locals())


def show_deleted(location, name, resource_group):
    '''
    Show a soft-deleted Azure Cognitive Services account.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account show-deleted", locals())


def list_deleted():
    '''
    List soft-deleted Azure Cognitive Services accounts.
    '''
    return _call_az("az cognitiveservices account list-deleted", locals())


def purge(location, name, resource_group):
    '''
    Purge a soft-deleted Azure Cognitive Services account.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account purge", locals())


def recover(location, name, resource_group):
    '''
    Recover a soft-deleted Azure Cognitive Services account.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account recover", locals())


def list_skus(kind=None, location=None, name=None, resource_group=None):
    '''
    Manage Azure Cognitive Services accounts.

    Optional Parameters:
    - kind -- the API name of cognitive services account
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account list-skus", locals())


def list_usage(name, resource_group):
    '''
    

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account list-usage", locals())


def list_kinds():
    return _call_az("az cognitiveservices account list-kinds", locals())




from .... pyaz_utils import _call_az

def show(database, location, name, server):
    '''
    Get a long term retention backup for a database.

    Required Parameters:
    - database -- Name of the Azure SQL Database. If specified (along with server name), retrieves all requested backups under this database.
    - location -- The location of the desired backups.
    - name -- The name of the LTR backup. Use 'az sql db ltr-backup show' or 'az sql db ltr-backup list' for backup name.
    - server -- Name of the Azure SQL Server. If specified, retrieves all requested backups under this server.
    '''
    return _call_az("az sql db ltr-backup show", locals())


def list(location, database=None, database_state=None, only_latest_per_database=None, resource_group=None, server=None):
    '''
    List the long term retention backups for a location, server or database.

    Required Parameters:
    - location -- The location of the desired backups.

    Optional Parameters:
    - database -- Name of the Azure SQL Database. If specified (along with server name), retrieves all requested backups under this database.
    - database_state -- 'All', 'Live', or 'Deleted'. Will fetch backups only from databases of specified state. If no state provied, defaults to 'All'.
    - only_latest_per_database -- If true, will only return the latest backup for each database
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL Server. If specified, retrieves all requested backups under this server.
    '''
    return _call_az("az sql db ltr-backup list", locals())


def delete(database, location, name, server, yes=None):
    '''
    Delete a long term retention backup.

    Required Parameters:
    - database -- Name of the Azure SQL Database. If specified (along with server name), retrieves all requested backups under this database.
    - location -- The location of the desired backups.
    - name -- The name of the LTR backup. Use 'az sql db ltr-backup show' or 'az sql db ltr-backup list' for backup name.
    - server -- Name of the Azure SQL Server. If specified, retrieves all requested backups under this server.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql db ltr-backup delete", locals())


def restore(backup_id, dest_database, dest_resource_group, dest_server, backup_storage_redundancy=None, no_wait=None):
    '''
    Restore a long term retention backup to a new database.

    Required Parameters:
    - backup_id -- The resource id of the long term retention backup to be restored. Use 'az sql db ltr-backup show' or 'az sql db ltr-backup list' for backup id.
    - dest_database -- Name of the database that will be created as the restore destination.
    - dest_resource_group -- Name of the resource group of the server to restore database to.
    - dest_server -- Name of the server to restore database to.

    Optional Parameters:
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az sql db ltr-backup restore", locals())


def wait(name, resource_group, server, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the database is met.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az sql db ltr-backup wait", locals())




from .... pyaz_utils import _call_az

def list(cluster_name, name, resource_group):
    '''
    List versions of a given managed application type.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sf managed-application-type version list", locals())


def delete(cluster_name, name, resource_group, version):
    '''
    Delete a managed application type version.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.
    '''
    return _call_az("az sf managed-application-type version delete", locals())


def show(cluster_name, name, resource_group, version):
    '''
    Show the properties of a managed application type version on an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.
    '''
    return _call_az("az sf managed-application-type version show", locals())


def create(cluster_name, name, package_url, resource_group, version, tags=None):
    '''
    Create a new managed application type on an Azure Service Fabric managed cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - package_url -- Specify the url of the application package sfpkg file.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.

    Optional Parameters:
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-application-type version create", locals())


def update(cluster_name, name, resource_group, version, package_url=None, tags=None):
    '''
    Update a managed application type version.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - name -- Specify the application type name.
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - version -- Specify the application type version.

    Optional Parameters:
    - package_url -- Specify the url of the application package sfpkg file.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az sf managed-application-type version update", locals())




'''
Manage event domain topics.
'''
from .... pyaz_utils import _call_az

def show(domain_name, name, resource_group):
    '''
    Get the details of a domain topic.

    Required Parameters:
    - domain_name -- Name of the domain.
    - name -- Name of the domain topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid domain topic show", locals())


def list(domain_name, resource_group, odata_query=None):
    '''
    List available topics in a domain.

    Required Parameters:
    - domain_name -- Name of the domain.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    '''
    return _call_az("az eventgrid domain topic list", locals())


def delete(domain_name, name, resource_group):
    '''
    Delete a domain topic under a domain.

    Required Parameters:
    - domain_name -- Name of the domain.
    - name -- Name of the domain topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid domain topic delete", locals())


def create(domain_name, name, resource_group):
    '''
    Create a domain topic under a domain.

    Required Parameters:
    - domain_name -- Name of the domain.
    - name -- Name of the domain topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid domain topic create", locals())




'''
Inspect the price sheet of an Azure subscription within a billing period.
'''
from ... pyaz_utils import _call_az

def show(billing_period_name=None, include_meter_details=None):
    '''
    Show the price sheet for an Azure subscription within a billing period.

    Optional Parameters:
    - billing_period_name -- Name of the billing period to get the price sheet.
    - include_meter_details -- Include meter details in the price sheet.
    '''
    return _call_az("az consumption pricesheet show", locals())




from .... pyaz_utils import _call_az

def show(name, profile_name, resource_group, type):
    '''
    Get the details of a traffic manager endpoint.

    Required Parameters:
    - name -- Endpoint name.
    - profile_name -- Name of parent profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Endpoint type.
    '''
    return _call_az("az network traffic-manager endpoint show", locals())


def delete(name, profile_name, resource_group, type):
    '''
    Delete a traffic manager endpoint.

    Required Parameters:
    - name -- Endpoint name.
    - profile_name -- Name of parent profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Endpoint type.
    '''
    return _call_az("az network traffic-manager endpoint delete", locals())


def create(name, profile_name, resource_group, type, custom_headers=None, endpoint_location=None, endpoint_monitor_status=None, endpoint_status=None, geo_mapping=None, min_child_endpoints=None, priority=None, subnets=None, target=None, target_resource_id=None, weight=None):
    '''
    Create a traffic manager endpoint.

    Required Parameters:
    - name -- Endpoint name.
    - profile_name -- Name of parent profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Endpoint type.

    Optional Parameters:
    - custom_headers -- Space-separated list of custom headers in KEY=VALUE format.
    - endpoint_location -- Location of the external or nested endpoints when using the 'Performance' routing method.
    - endpoint_monitor_status -- The monitoring status of the endpoint.
    - endpoint_status -- The status of the endpoint. If enabled the endpoint is probed for endpoint health and included in the traffic routing method.
    - geo_mapping -- Space-separated list of country/region codes mapped to this endpoint when using the 'Geographic' routing method.
    - min_child_endpoints -- The minimum number of endpoints that must be available in the child profile for the parent profile to be considered available. Only applicable to an endpoint of type 'NestedEndpoints'.
    - priority -- Priority of the endpoint when using the 'Priority' traffic routing method. Values range from 1 to 1000, with lower values representing higher priority.
    - subnets -- Space-separated list of subnet CIDR prefixes (10.0.0.0/24) or subnet ranges (10.0.0.0-11.0.0.0).
    - target -- Fully-qualified DNS name of the endpoint.
    - target_resource_id -- The Azure Resource URI of the endpoint. Not applicable for endpoints of type 'ExternalEndpoints'.
    - weight -- Weight of the endpoint when using the 'Weighted' traffic routing method. Values range from 1 to 1000.
    '''
    return _call_az("az network traffic-manager endpoint create", locals())


def list(profile_name, resource_group, type=None):
    '''
    List traffic manager endpoints.

    Required Parameters:
    - profile_name -- Name of parent profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - type -- Endpoint type.
    '''
    return _call_az("az network traffic-manager endpoint list", locals())


def update(name, profile_name, resource_group, add=None, custom_headers=None, endpoint_location=None, endpoint_monitor_status=None, endpoint_status=None, force_string=None, geo_mapping=None, min_child_endpoints=None, priority=None, remove=None, set=None, subnets=None, target=None, target_resource_id=None, type=None, weight=None):
    '''
    Update a traffic manager endpoint.

    Required Parameters:
    - name -- Endpoint name.
    - profile_name -- Name of parent profile.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - custom_headers -- Space-separated list of custom headers in KEY=VALUE format.
    - endpoint_location -- Location of the external or nested endpoints when using the 'Performance' routing method.
    - endpoint_monitor_status -- The monitoring status of the endpoint.
    - endpoint_status -- The status of the endpoint. If enabled the endpoint is probed for endpoint health and included in the traffic routing method.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - geo_mapping -- Space-separated list of country/region codes mapped to this endpoint when using the 'Geographic' routing method.
    - min_child_endpoints -- The minimum number of endpoints that must be available in the child profile for the parent profile to be considered available. Only applicable to an endpoint of type 'NestedEndpoints'.
    - priority -- Priority of the endpoint when using the 'Priority' traffic routing method. Values range from 1 to 1000, with lower values representing higher priority.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - subnets -- Space-separated list of subnet CIDR prefixes (10.0.0.0/24) or subnet ranges (10.0.0.0-11.0.0.0).
    - target -- Fully-qualified DNS name of the endpoint.
    - target_resource_id -- The Azure Resource URI of the endpoint. Not applicable for endpoints of type 'ExternalEndpoints'.
    - type -- Endpoint type.
    - weight -- Weight of the endpoint when using the 'Weighted' traffic routing method. Values range from 1 to 1000.
    '''
    return _call_az("az network traffic-manager endpoint update", locals())


def show_geographic_hierarchy():
    '''
    Get the default geographic hierarchy used by the geographic traffic routing method.
    '''
    return _call_az("az network traffic-manager endpoint show-geographic-hierarchy", locals())




'''
Manage Azure Cosmos DB databases.
'''
from ... pyaz_utils import _call_az

def show(db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    Shows an Azure Cosmos DB database

    Required Parameters:
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb database show", locals())


def list(key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    Lists all Azure Cosmos DB databases

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb database list", locals())


def exists(db_name, key=None, name=None, resource_group_name=None, url_connection=None):
    '''
    Returns a boolean indicating whether the database exists

    Required Parameters:
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb database exists", locals())


def create(db_name, key=None, name=None, resource_group_name=None, throughput=None, url_connection=None):
    '''
    Creates an Azure Cosmos DB database

    Required Parameters:
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - throughput -- Offer Throughput (RU/s)
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    '''
    return _call_az("az cosmosdb database create", locals())


def delete(db_name, key=None, name=None, resource_group_name=None, url_connection=None, yes=None):
    '''
    Deletes an Azure Cosmos DB database

    Required Parameters:
    - db_name -- Database Name

    Optional Parameters:
    - key -- Cosmos DB account key. Must be used in conjunction with cosmosdb account name or url-connection.
    - name -- Cosmos DB account name. Must be used in conjunction with either name of the resource group or cosmosdb account key.
    - resource_group_name -- name of the resource group. Must be used in conjunction with cosmosdb account name.
    - url_connection -- Cosmos DB account url connection. Must be used in conjunction with cosmosdb account key.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az cosmosdb database delete", locals())




'''
manage an application's password or certificate credentials
'''
from .... pyaz_utils import _call_az

def reset(id, append=None, cert=None, create_cert=None, credential_description=None, end_date=None, keyvault=None, password=None, years=None):
    '''
    Append or overwrite an application's password or certificate credentials

    Required Parameters:
    - id -- identifier uri, application id, or object id

    Optional Parameters:
    - append -- Append the new credential instead of overwriting.
    - cert -- Certificate to use for credentials
    - create_cert -- Create a self-signed certificate to use for the credential
    - credential_description -- the description of the password
    - end_date -- Date or datetime after which credentials expire(e.g. '2017-12-31T11:59:59+00:00' or '2017-12-31'). Default value is one year after current time
    - keyvault -- Name or ID of a KeyVault to use for creating or retrieving certificates.
    - password -- app password, aka 'client secret'
    - years -- Number of years for which the credentials will be valid
    '''
    return _call_az("az ad app credential reset", locals())


def list(id, cert=None):
    '''
    List an application's password or certificate credential metadata. (The content of the password or certificate credential is not retrievable.)

    Required Parameters:
    - id -- identifier uri, application id, or object id

    Optional Parameters:
    - cert -- a certificate based credential
    '''
    return _call_az("az ad app credential list", locals())


def delete(id, key_id, cert=None):
    '''
    delete an application's password or certificate credentials

    Required Parameters:
    - id -- identifier uri, application id, or object id
    - key_id -- credential key id

    Optional Parameters:
    - cert -- a certificate based credential
    '''
    return _call_az("az ad app credential delete", locals())




'''
Manage Azure Cloud Storage resources.
'''
from .. pyaz_utils import _call_az
from . import account, container, container_rm, cors, directory, entity, file, fs, logging, message, metrics, queue, share, share_rm, table


def remove(account_key=None, account_name=None, connection_string=None, container_name=None, exclude_path=None, exclude_pattern=None, include_path=None, include_pattern=None, name=None, path=None, recursive=None, sas_token=None, share_name=None):
    '''
    Delete blobs or files from Azure Storage.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - container_name -- The container name.
    - exclude_path -- Exclude these paths. This option does not support wildcard characters (*). Checks relative path prefix. For example: myFolder;myFolder/subDirName/file.pdf.
    - exclude_pattern -- Exclude these files where the name matches the pattern list. For example: *.jpg;*.pdf;exactName. This option supports wildcard characters (*)
    - include_path -- Include only these paths. This option does not support wildcard characters (*). Checks relative path prefix. For example:myFolder;myFolder/subDirName/file.pdf
    - include_pattern -- Include only these files where the name matches the pattern list. For example: *.jpg;*.pdf;exactName. This option supports wildcard characters (*)
    - name -- The blob name.
    - path -- The path to the file within the file share.
    - recursive -- Look into sub-directories recursively.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - share_name -- The file share name.
    '''
    return _call_az("az storage remove", locals())


def copy(account_key=None, account_name=None, blob_type=None, cap_mbps=None, connection_string=None, content_type=None, destination=None, destination_blob=None, destination_container=None, destination_file_path=None, destination_share=None, exclude_path=None, exclude_pattern=None, follow_symlinks=None, include_path=None, include_pattern=None, preserve_s2s_access_tier=None, put_md5=None, recursive=None, sas_token=None, source=None, source_account_key=None, source_account_name=None, source_blob=None, source_connection_string=None, source_container=None, source_file_path=None, source_sas=None, source_share=None):
    '''
    Copy files or directories to or from Azure storage.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name of copy destination
    - blob_type -- The type of blob at the destination.
    - cap_mbps -- Caps the transfer rate, in megabits per second. Moment-by-moment throughput might vary slightly from the cap. If this option is set to zero, or it is omitted, the throughput isn't capped. 
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_type -- Specify content type of the file. 
    - destination -- The path/url of copy destination. It can be a local path, an url to azure storage server. If you provide destination parameter here, you do not need to provide arguments in copy destination arguments group and copy destination arguments will be deprecated in future.
    - destination_blob -- Blob name in blob container of copy destination storage account
    - destination_container -- Container name of copy destination storage account
    - destination_file_path -- File path in file share of copy destination storage account
    - destination_share -- File share name of copy destination storage account
    - exclude_path -- Exclude these paths. This option does not support wildcard characters (*). Checks relative path prefix. For example: myFolder;myFolder/subDirName/file.pdf.
    - exclude_pattern -- Exclude these files where the name matches the pattern list. For example: *.jpg;*.pdf;exactName. This option supports wildcard characters (*)
    - follow_symlinks -- Follow symbolic links when uploading from local file system.
    - include_path -- Include only these paths. This option does not support wildcard characters (*). Checks relative path prefix. For example:myFolder;myFolder/subDirName/file.pdf
    - include_pattern -- Include only these files where the name matches the pattern list. For example: *.jpg;*.pdf;exactName. This option supports wildcard characters (*)
    - preserve_s2s_access_tier -- Preserve access tier during service to service copy. Please refer to https://docs.microsoft.com/azure/storage/blobs/storage-blob-storage-tiers to ensure destination storage account support setting access tier. In the cases that setting access tier is not supported, please use `--preserve-s2s-access-tier false` to bypass copying access tier. (Default true)
    - put_md5 -- Create an MD5 hash of each file, and save the hash as the Content-MD5 property of the destination blob/file.Only available when uploading.
    - recursive -- Look into sub-directories recursively.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - source -- The path/url of copy source. It can be a local path, an url to azure storage server or AWS S3 buckets. If you provide source parameter here, you do not need to provide arguments in copy source arguments group and copy source arguments will be deprecated in future.
    - source_account_key -- Account key of copy source storage account. Must be used in conjunction with source storage account name.
    - source_account_name -- Account name of copy source storage account.
    - source_blob -- Blob name in blob container of copy source storage account
    - source_connection_string -- Connection string of source storage account.
    - source_container -- Container name of copy source storage account
    - source_file_path -- File path in file share of copy source storage account
    - source_sas -- Shared Access Signature (SAS) token of copy source. Must be used in conjunction with source storage account name.
    - source_share -- File share name of copy source storage account
    '''
    return _call_az("az storage copy", locals())




'''
Manage Batch jobs.
'''
from ... pyaz_utils import _call_az
from . import all_statistics, prep_release_status, task_counts


def create(account_endpoint=None, account_key=None, account_name=None, id=None, job_manager_task_command_line=None, job_manager_task_environment_settings=None, job_manager_task_id=None, job_manager_task_resource_files=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, max_parallel_tasks=None, metadata=None, pool_id=None, priority=None, required_slots=None, uses_task_dependencies=None):
    '''
    Add a job to a Batch account.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores, and cannot contain more than 64 characters. The ID is case-preserving and case-insensitive (that is, you may not have two IDs within an Account that differ only by case).
    - job_manager_task_command_line -- Required. The command line does not run under a shell, and therefore cannot take advantage of shell features such as environment variable expansion. If you want to take advantage of such features, you should invoke the shell in the command line, for example using "cmd /c MyCommand" in Windows or "/bin/sh -c MyCommand" in Linux. If the command line refers to file paths, it should use a relative path (relative to the Task working directory), or use the Batch provided environment variable (https://docs.microsoft.com/en-us/azure/batch/batch-compute-node-environment-variables).
    - job_manager_task_environment_settings --  Space-separated values in 'key=value' format.
    - job_manager_task_id -- Required. The ID can contain any combination of alphanumeric characters including hyphens and underscores and cannot contain more than 64 characters.
    - job_manager_task_resource_files -- Files listed under this element are located in the Task's working directory. There is a maximum size for the list of resource files.  When the max size is exceeded, the request will fail and the response error code will be RequestEntityTooLarge. If this occurs, the collection of ResourceFiles must be reduced in size. This can be achieved using .zip files, Application Packages, or Docker Containers. Space-separated resource references in filename=httpurl format.
    - job_max_task_retry_count -- The maximum number of times each Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries. The Batch service will try each Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries a Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry Tasks. If the maximum retry count is -1, the Batch service retries Tasks without limit. The default value is 0 (no retries).
    - job_max_wall_clock_time -- If the Job does not complete within the time limit, the Batch service terminates it and any Tasks that are still running. In this case, the termination reason will be MaxWallClockTimeExpiry. If this property is not specified, there is no time limit on how long the Job may run. Expected format is an ISO-8601 duration.
    - json_file -- A file containing the job specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Job Arguments' are ignored.
    - max_parallel_tasks -- The maximum number of tasks that can be executed in parallel for the job. The value of maxParallelTasks must be -1 or greater than 0 if specified. If not specified, the default value is -1, which means there's no limit to the number of tasks that can be run at once. You can update a job's maxParallelTasks after it has been created using the update job API. Default value: -1 .
    - metadata -- The Batch service does not assign any meaning to metadata; it is solely for the use of user code. Space-separated values in 'key=value' format.
    - pool_id -- The id of an existing pool. All the tasks of the job will run on the specified pool.
    - priority -- The priority of the Job. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. The default value is 0.
    - required_slots -- The number of scheduling slots that the Task requires to run. The default is 1. A Task can only be scheduled to run on a compute node if the node has enough free scheduling slots available. For multi-instance Tasks, this property is not supported and must not be specified.
    - uses_task_dependencies -- Whether Tasks in the Job can define dependencies on each other. The default is false. True if flag present.
    '''
    return _call_az("az batch job create", locals())


def delete(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, yes=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job to delete.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batch job delete", locals())


def show(job_id, account_endpoint=None, account_key=None, account_name=None, expand=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, select=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand -- An OData $expand clause.
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - select -- An OData $select clause.
    '''
    return _call_az("az batch job show", locals())


def set(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, max_parallel_tasks=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None):
    '''
    Update the properties of a Batch job. Updating a property in a subgroup will reset the unspecified properties of that group.

    Required Parameters:
    - job_id -- The ID of the Job whose properties you want to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - job_max_task_retry_count -- The maximum number of times each Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries. The Batch service will try each Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries a Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry Tasks. If the maximum retry count is -1, the Batch service retries Tasks without limit. The default value is 0 (no retries).
    - job_max_wall_clock_time -- If the Job does not complete within the time limit, the Batch service terminates it and any Tasks that are still running. In this case, the termination reason will be MaxWallClockTimeExpiry. If this property is not specified, there is no time limit on how long the Job may run. Expected format is an ISO-8601 duration.
    - json_file -- A file containing the job patch parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Job Arguments' are ignored.
    - max_parallel_tasks -- The maximum number of tasks that can be executed in parallel for the job. The value of maxParallelTasks must be -1 or greater than 0 if specified. If not specified, the default value is -1, which means there's no limit to the number of tasks that can be run at once. You can update a job's maxParallelTasks after it has been created using the update job API.
    - metadata -- If omitted, the existing Job metadata is left unchanged. Space-separated values in 'key=value' format.
    - on_all_tasks_complete -- The action the Batch service should take when all Tasks in the Job are in the completed state. If omitted, the completion behavior is left unchanged. You may not change the value from terminatejob to noaction - that is, once you have engaged automatic Job termination, you cannot turn it off again. If you try to do this, the request fails with an 'invalid property value' error response; if you are calling the REST API directly, the HTTP status code is 400 (Bad Request).
    - pool_id -- The id of an existing pool. All the tasks of the job will run on the specified pool.
    - priority -- The priority of the Job. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. If omitted, the priority of the Job is left unchanged.
    '''
    return _call_az("az batch job set", locals())


def reset(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, job_max_task_retry_count=None, job_max_wall_clock_time=None, json_file=None, metadata=None, on_all_tasks_complete=None, pool_id=None, priority=None):
    '''
    Update the properties of a Batch job. Unspecified properties which can be updated are reset to their defaults.

    Required Parameters:
    - job_id -- The ID of the Job whose properties you want to update.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - job_max_task_retry_count -- The maximum number of times each Task may be retried. The Batch service retries a Task if its exit code is nonzero. Note that this value specifically controls the number of retries. The Batch service will try each Task once, and may then retry up to this limit. For example, if the maximum retry count is 3, Batch tries a Task up to 4 times (one initial try and 3 retries). If the maximum retry count is 0, the Batch service does not retry Tasks. If the maximum retry count is -1, the Batch service retries Tasks without limit. The default value is 0 (no retries).
    - job_max_wall_clock_time -- If the Job does not complete within the time limit, the Batch service terminates it and any Tasks that are still running. In this case, the termination reason will be MaxWallClockTimeExpiry. If this property is not specified, there is no time limit on how long the Job may run. Expected format is an ISO-8601 duration.
    - json_file -- A file containing the job update parameter specification in JSON (formatted to match the respective REST API body). If this parameter is specified, all 'Job Arguments' are ignored.
    - metadata -- If omitted, it takes the default value of an empty list; in effect, any existing metadata is deleted. Space-separated values in 'key=value' format.
    - on_all_tasks_complete -- The action the Batch service should take when all Tasks in the Job are in the completed state. If omitted, the completion behavior is set to noaction. If the current value is terminatejob, this is an error because a Job's completion behavior may not be changed from terminatejob to noaction. You may not change the value from terminatejob to noaction - that is, once you have engaged automatic Job termination, you cannot turn it off again. If you try to do this, the request fails and Batch returns status code 400 (Bad Request) and an 'invalid property value' error response. If you do not specify this element in a PUT request, it is equivalent to passing noaction. This is an error if the current value is terminatejob.
    - pool_id -- The id of an existing pool. All the tasks of the job will run on the specified pool.
    - priority -- The priority of the Job. Priority values can range from -1000 to 1000, with -1000 being the lowest priority and 1000 being the highest priority. If omitted, it is set to the default value 0.
    '''
    return _call_az("az batch job reset", locals())


def list(account_endpoint=None, account_key=None, account_name=None, expand=None, filter=None, job_schedule_id=None, select=None):
    '''
    List all of the jobs or job schedule in a Batch account.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- The Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- The Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - expand --  An OData $expand clause.
    - filter --  An OData $filter clause.
    - job_schedule_id -- The ID of the job schedule from which you want to get a list of jobs. If omitted, lists all jobs in the account.
    - select --  An OData $select clause.
    '''
    return _call_az("az batch job list", locals())


def disable(job_id, account_endpoint=None, account_key=None, account_name=None, disable_tasks=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job to disable.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - disable_tasks -- Possible values include: 'requeue', 'terminate', 'wait'
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch job disable", locals())


def enable(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job to enable.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    '''
    return _call_az("az batch job enable", locals())


def stop(job_id, account_endpoint=None, account_key=None, account_name=None, if_match=None, if_modified_since=None, if_none_match=None, if_unmodified_since=None, terminate_reason=None):
    '''
    Stop a running Batch job.

    Required Parameters:
    - job_id -- The ID of the Job to terminate.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - if_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service exactly matches the value specified by the client.
    - if_modified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has been modified since the specified time.
    - if_none_match -- An ETag value associated with the version of the resource known to the client. The operation will be performed only if the resource's current ETag on the service does not match the value specified by the client.
    - if_unmodified_since -- A timestamp indicating the last modified time of the resource known to the client. The operation will be performed only if the resource on the service has not been modified since the specified time.
    - terminate_reason -- 
    '''
    return _call_az("az batch job stop", locals())




'''
Commands to manage experiments.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, workspace):
    '''
    Create an experiment.

    Required Parameters:
    - name -- Name of experiment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai experiment create", locals())


def show(name, resource_group, workspace):
    '''
    Show information about an experiment.

    Required Parameters:
    - name -- Name of experiment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai experiment show", locals())


def list(resource_group, workspace):
    '''
    List experiments.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai experiment list", locals())


def delete(name, resource_group, workspace, no_wait=None, yes=None):
    '''
    Delete an experiment.

    Required Parameters:
    - name -- Name of experiment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az batchai experiment delete", locals())




'''
Manage subtask information of a Batch task.
'''
from .... pyaz_utils import _call_az

def list(job_id, task_id, account_endpoint=None, account_key=None, account_name=None, select=None):
    '''
    

    Required Parameters:
    - job_id -- The ID of the Job.
    - task_id -- The ID of the Task.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    - select -- An OData $select clause.
    '''
    return _call_az("az batch task subtask list", locals())




from ..... pyaz_utils import _call_az

def show(name, resource_group, zone_name, record_type=None):
    '''
    Get the details of a CNAME record set.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the zone.

    Optional Parameters:
    - record_type -- ==SUPPRESS==
    '''
    return _call_az("az network dns record-set cname show", locals())


def delete(name, resource_group, zone_name, if_match=None, record_type=None, yes=None):
    '''
    Delete a CNAME record set and its associated record.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the zone.

    Optional Parameters:
    - if_match -- The etag of the record set. Omit this value to always delete the current record set. Specify the last-seen etag value to prevent accidentally deleting any concurrent changes.
    - record_type -- ==SUPPRESS==
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network dns record-set cname delete", locals())


def list(resource_group, zone_name, record_type=None):
    '''
    List the CNAME record set in a zone.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the zone.

    Optional Parameters:
    - record_type -- ==SUPPRESS==
    '''
    return _call_az("az network dns record-set cname list", locals())


def create(name, resource_group, zone_name, if_match=None, if_none_match=None, metadata=None, record_set_type=None, target_resource=None, ttl=None):
    '''
    Create an empty CNAME record set.

    Required Parameters:
    - name -- The name of the record set, relative to the name of the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the zone.

    Optional Parameters:
    - if_match -- The etag of the record set. Omit this value to always overwrite the current record set. Specify the last-seen etag value to prevent accidentally overwriting any concurrent changes.
    - if_none_match -- Create the record set only if it does not already exist.
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - record_set_type -- ==SUPPRESS==
    - target_resource -- ID of an Azure resource from which the DNS resource value is taken.
    - ttl -- Record set TTL (time-to-live)
    '''
    return _call_az("az network dns record-set cname create", locals())


def set_record(cname, record_set_name, resource_group, zone_name, if_none_match=None, ttl=None):
    '''
    Set the value of a CNAME record.

    Required Parameters:
    - cname -- Value of the cname record-set. It should be Canonical name.
    - record_set_name -- The name of the record set relative to the zone. Creates a new record set if one does not exist.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the zone.

    Optional Parameters:
    - if_none_match -- Create the record set only if it does not already exist.
    - ttl -- Record set TTL (time-to-live)
    '''
    return _call_az("az network dns record-set cname set-record", locals())


def remove_record(cname, record_set_name, resource_group, zone_name, keep_empty_record_set=None):
    '''
    Remove a CNAME record from its record set.

    Required Parameters:
    - cname -- Value of the cname record-set. It should be Canonical name.
    - record_set_name -- The name of the record set relative to the zone.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - zone_name -- The name of the zone.

    Optional Parameters:
    - keep_empty_record_set -- Keep the empty record set if the last record is removed.
    '''
    return _call_az("az network dns record-set cname remove-record", locals())




'''
Manage function apps. To install the Azure Functions Core tools see https://github.com/Azure/azure-functions-core-tools
'''
from .. pyaz_utils import _call_az
from . import config, cors, function, hybrid_connection, identity, keys, plan, vnet_integration


def create(name, resource_group, storage_account, app_insights=None, app_insights_key=None, assign_identity=None, consumption_plan_location=None, deployment_container_image_name=None, deployment_local_git=None, deployment_source_branch=None, deployment_source_url=None, disable_app_insights=None, docker_registry_server_password=None, docker_registry_server_user=None, functions_version=None, os_type=None, plan=None, role=None, runtime=None, runtime_version=None, scope=None, subnet=None, tags=None, vnet=None):
    '''
    Create a function app.

    Required Parameters:
    - name -- name of the new function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account -- Provide a string value of a Storage Account in the provided Resource Group. Or Resource ID of a Storage Account in a different Resource Group

    Optional Parameters:
    - app_insights -- Name of the existing App Insights project to be added to the function app. Must be in the same resource group.
    - app_insights_key -- Instrumentation key of App Insights to be added.
    - assign_identity -- accept system or user assigned identities separated by spaces. Use '[system]' to refer system assigned identity, or a resource id to refer user assigned identity. Check out help for more examples
    - consumption_plan_location -- Geographic location where function app will be hosted. Use `az functionapp list-consumption-locations` to view available locations.
    - deployment_container_image_name -- Container image name from Docker Hub, e.g. publisher/image-name:tag
    - deployment_local_git -- enable local git
    - deployment_source_branch -- the branch to deploy
    - deployment_source_url -- Git repository URL to link with manual integration
    - disable_app_insights -- Disable creating application insights resource during functionapp create. No logs will be available.
    - docker_registry_server_password -- The container registry server password. Required for private registries.
    - docker_registry_server_user -- The container registry server username.
    - functions_version -- The functions app version. NOTE: This will be required starting the next release cycle
    - os_type -- Set the OS type for the app to be created.
    - plan -- name or resource id of the functionapp app service plan. Use 'appservice plan create' to get one. If using an App Service plan from a different resource group, the full resource id must be used and not the plan name.
    - role -- Role name or id the system assigned identity will have
    - runtime -- The functions runtime stack.
    - runtime_version -- The version of the functions runtime stack. Allowed values for each --runtime are: dotnet-isolated -> [5.0 (preview), 6.0], node -> [12, 14], java -> [8, 11], powershell -> [7.0 (preview)], python -> [3.6, 3.7, 3.8, 3.9]
    - scope -- Scope that the system assigned identity can access
    - subnet -- Name or resource ID of the pre-existing subnet to have the webapp join. The --vnet is argument also needed if specifying subnet by name.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet -- Name or resource ID of the regional virtual network. If there are multiple vnets of the same name across different resource groups, use vnet resource id to specify which vnet to use. If vnet name is used, by default, the vnet in the same resource group as the webapp will be used. Must be used with --subnet argument.
    '''
    return _call_az("az functionapp create", locals())


def list(resource_group=None):
    '''
    List function apps.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az functionapp list", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a function app.

    Required Parameters:
    - name -- name of the function app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp show", locals())


def delete(name, resource_group, slot=None):
    '''
    Delete a function app.

    Required Parameters:
    - name -- name of the function app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp delete", locals())


def stop(name, resource_group, slot=None):
    '''
    Stop a function app.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp stop", locals())


def start(name, resource_group, slot=None):
    '''
    Start a function app.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp start", locals())


def restart(name, resource_group, slot=None):
    '''
    Restart a function app.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp restart", locals())


def list_consumption_locations():
    '''
    List available locations for running function apps.
    '''
    return _call_az("az functionapp list-consumption-locations", locals())


def deploy(name, resource_group, async_=None, clean=None, ignore_stack=None, restart=None, slot=None, src_path=None, src_url=None, target_path=None, timeout=None, type=None):
    '''
    Deploys a provided artifact to Azure functionapp.

    Required Parameters:
    - name -- Name of the function app to deploy to.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - async_ -- Asynchronous deployment
    - clean -- If true, cleans the target directory prior to deploying the file(s). Default value is determined based on artifact type.
    - ignore_stack -- If true, any stack-specific defaults are ignored.
    - restart -- If true, the web app will be restarted following the deployment, default value is true. Set this to false if you are deploying multiple artifacts and do not want to restart the site on the earlier deployments.
    - slot -- The name of the slot. Default to the productions slot if not specified.
    - src_path -- Path of the artifact to be deployed. Ex: "myapp.zip" or "/myworkspace/apps/myapp.war"
    - src_url -- URL of the artifact. The webapp will pull the artifact from this URL. Ex: "http://mysite.com/files/myapp.war?key=123"
    - target_path -- Absolute path that the artifact should be deployed to. Defaults to "home/site/wwwroot/". Ex: "/home/site/deployments/tools/", "/home/site/scripts/startup-script.sh".
    - timeout -- Timeout for the deployment operation in milliseconds.
    - type -- Used to override the type of artifact being deployed.
    '''
    return _call_az("az functionapp deploy", locals())


def update(name, resource_group, add=None, force=None, force_string=None, plan=None, remove=None, set=None, slot=None):
    '''
    Update a function app.

    Required Parameters:
    - name -- name of the function app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force -- Required if attempting to migrate functionapp from Premium to Consumption --plan.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - plan -- The name or resource id of the plan to update the functionapp with.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az functionapp update", locals())




'''
Manage Classic Azure Monitor logs integration on an HDInsight cluster.
'''
from ... pyaz_utils import _call_az

def show(name, resource_group):
    '''
    Get the status of Classic Azure Monitor logs integration on an HDInsight cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight monitor show", locals())


def enable(name, resource_group, workspace, no_validation_timeout=None, primary_key=None):
    '''
    Enable the Classic Azure Monitor logs integration on an HDInsight cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- The name, resource ID or workspace ID of Log Analytics workspace.

    Optional Parameters:
    - no_validation_timeout -- Permit timeout error during argument validation phase. If omitted, validation timeout error will be permitted.
    - primary_key -- The certificate for the Log Analytics workspace. Required when workspace ID is provided.
    '''
    return _call_az("az hdinsight monitor enable", locals())


def disable(name, resource_group):
    '''
    Disable the Classic Azure Monitor logs integration on an HDInsight cluster.

    Required Parameters:
    - name -- The name of the cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az hdinsight monitor disable", locals())




from ..... pyaz_utils import _call_az

def add(address_pool, identifier, lb_name, protocol, resource_group, type, port=None):
    '''
    Add one tunnel interface into the load balance tunnel interface pool.

    Required Parameters:
    - address_pool -- The name of the backend address pool. If only one exists, omit to use as default.
    - identifier -- Identifier of gateway load balancer tunnel interface.
    - lb_name -- The load balancer name.
    - protocol -- Protocol of gateway load balancer tunnel interface.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - type -- Traffic type of gateway load balancer tunnel interface.

    Optional Parameters:
    - port -- Port of gateway load balancer tunnel interface.
    '''
    return _call_az("az network lb address-pool tunnel-interface add", locals())


def update(address_pool, index, lb_name, resource_group, identifier=None, port=None, protocol=None, type=None):
    '''
    update one tunnel interface of load balance tunnel interface pool.

    Required Parameters:
    - address_pool -- The name of the backend address pool. If only one exists, omit to use as default.
    - index -- Index of the tunnel interfaces to change
    - lb_name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identifier -- Identifier of gateway load balancer tunnel interface.
    - port -- Port of gateway load balancer tunnel interface.
    - protocol -- Protocol of gateway load balancer tunnel interface.
    - type -- Traffic type of gateway load balancer tunnel interface.
    '''
    return _call_az("az network lb address-pool tunnel-interface update", locals())


def remove(address_pool, index, lb_name, resource_group):
    '''
    Remove one tunnel interface from the load balance tunnel interface pool.

    Required Parameters:
    - address_pool -- The name of the backend address pool. If only one exists, omit to use as default.
    - index -- Index of the tunnel interfaces to change
    - lb_name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool tunnel-interface remove", locals())


def list(address_pool, lb_name, resource_group):
    '''
    List all tunnel interfacees of the load balance tunnel interface pool.

    Required Parameters:
    - address_pool -- The name of the backend address pool. If only one exists, omit to use as default.
    - lb_name -- The load balancer name.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network lb address-pool tunnel-interface list", locals())




'''
Manage private registries with Azure Container Registries.
'''
from .. pyaz_utils import _call_az
from . import agentpool, connected_registry, credential, encryption, helm, identity, network_rule, pack, private_endpoint_connection, private_link_resource, replication, repository, scope_map, task, taskrun, token, webhook


def check_name(name):
    '''
    Checks if an Azure Container Registry name is valid and available for use.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    '''
    return _call_az("az acr check-name", locals())


def list(resource_group=None):
    '''
    Lists all the container registries under the current subscription.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr list", locals())


def create(name, resource_group, sku, admin_enabled=None, allow_exports=None, allow_trusted_services=None, default_action=None, identity=None, key_encryption_key=None, location=None, public_network_enabled=None, tags=None, workspace=None, zone_redundancy=None):
    '''
    Create an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - sku -- The SKU of the container registry

    Optional Parameters:
    - admin_enabled -- Indicates whether the admin user is enabled
    - allow_exports -- Configure exportPolicy to allow/disallow artifacts from being exported from this registry. Artifacts can be exported via import or transfer operations. For more information, please visit https://aka.ms/acr/export-policy.
    - allow_trusted_services -- Allow trusted Azure Services to access network restricted registries. For more information, please visit https://aka.ms/acr/trusted-services. The Default is to allow.
    - default_action -- Default action to apply when no rule matches. Only applicable to Premium SKU.
    - identity -- Use assigned managed identity resource id or name if in the same resource group
    - key_encryption_key -- Key vault key uri. To enable automated rotation, provide a version-less key uri. For manual rotation, provide a versioned key uri.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - public_network_enabled -- Allow public network access for the container registry. The Default is to allow.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - workspace -- Name or ID of the Log Analytics workspace to send registry diagnostic logs to. All events will be enabled. You can use "az monitor log-analytics workspace create" to create one. Extra billing may apply.
    - zone_redundancy -- Indicates whether or not zone redundancy should be enabled for this registry or replication. For more information, such as supported locations, please visit https://aka.ms/acr/az. Zone-redundancy cannot be updated. Defaults to 'Disabled'.
    '''
    return _call_az("az acr create", locals())


def delete(name, resource_group=None, yes=None):
    '''
    Deletes an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr delete", locals())


def show(name, resource_group=None):
    '''
    Get the details of an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr show", locals())


def show_usage(name, resource_group=None):
    '''
    Get the storage usage for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr show-usage", locals())


def show_endpoints(name, resource_group=None):
    '''
    Display registry endpoints

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr show-endpoints", locals())


def update(name, add=None, admin_enabled=None, allow_exports=None, allow_trusted_services=None, anonymous_pull_enabled=None, data_endpoint_enabled=None, default_action=None, force_string=None, public_network_enabled=None, remove=None, resource_group=None, set=None, sku=None, tags=None):
    '''
    Update an Azure Container Registry.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - admin_enabled -- Indicates whether the admin user is enabled
    - allow_exports -- Configure exportPolicy to allow/disallow artifacts from being exported from this registry. Artifacts can be exported via import or transfer operations. For more information, please visit https://aka.ms/acr/export-policy.
    - allow_trusted_services -- Allow trusted Azure Services to access network restricted registries. For more information, please visit https://aka.ms/acr/trusted-services.
    - anonymous_pull_enabled -- Enable registry-wide pull from unauthenticated clients
    - data_endpoint_enabled -- Enable dedicated data endpoint for client firewall configuration
    - default_action -- Default action to apply when no rule matches. Only applicable to Premium SKU.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - public_network_enabled -- Allow public network access for the container registry.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - sku -- The SKU of the container registry
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az acr update", locals())


def login(name, expose_token=None, password=None, resource_group=None, suffix=None, username=None):
    '''
    Log in to an Azure Container Registry through the Docker CLI.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - expose_token -- Expose access token instead of automatically logging in through Docker CLI
    - password -- The password used to log into a container registry
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - suffix -- The tenant suffix in registry login server. You may specify '--suffix tenant' if your registry login server is in the format 'registry-tenant.azurecr.io'. Applicable if you're accessing the registry from a different subscription or you have permission to access images but not the permission to manage the registry resource.
    - username -- The username used to log into a container registry
    '''
    return _call_az("az acr login", locals())


def import_(name, source, force=None, image=None, no_wait=None, password=None, registry=None, repository=None, resource_group=None, username=None):
    '''
    Imports an image to an Azure Container Registry from another Container Registry. Import removes the need to docker pull, docker tag, docker push. For larger images consider using `--no-wait`.

    Required Parameters:
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - source -- Source image name or fully qualified source containing the registry login server. If `--registry` is used, `--source` will always be interpreted as a source image, even if it contains the login server.

    Optional Parameters:
    - force -- Overwrite the existing tag of the image to be imported.
    - image -- The name and tag of the image using the format: '-t repo/image:tag'. Multiple tags are supported by passing -t multiple times.
    - no_wait -- Do not wait for the import to complete and return immediately after queuing the import.
    - password -- The password of source container registry
    - registry -- The source Azure container registry. This can be name, login server or resource ID of the source registry.
    - repository -- The repository name for a manifest-only copy of images. Multiple copies supported by passing --repository multiple times.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - username -- The username of source container registry
    '''
    return _call_az("az acr import", locals())


def build(registry, agent_pool=None, auth_mode=None, build_arg=None, file=None, image=None, log_template=None, no_format=None, no_logs=None, no_push=None, no_wait=None, platform=None, resource_group=None, secret_build_arg=None, target=None, timeout=None):
    '''
    Queues a quick build, providing streaming logs for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - agent_pool -- The name of the agent pool.
    - auth_mode -- Auth mode of the source registry.
    - build_arg -- Build argument in '--build-arg name[=value]' format. Multiples supported by passing --build-arg multiple times.
    - file -- The relative path of the the docker file to the source code root folder. Default to 'Dockerfile'.
    - image -- The name and tag of the image using the format: '-t repo/image:tag'. Multiple tags are supported by passing -t multiple times.
    - log_template -- The repository and tag template for run log artifact using the format: 'log/repo:tag' (e.g., 'acr/logs:{{.Run.ID}}'). Only applicable to CMK enabled registry.
    - no_format -- Indicates whether the logs should be displayed in raw format
    - no_logs -- Do not show logs after successfully queuing the build.
    - no_push -- Indicates whether the image built should be pushed to the registry.
    - no_wait -- Do not wait for the build to complete and return immediately after queuing the build.
    - platform -- The platform where build/task is run, Eg, 'windows' and 'linux'. When it's used in build commands, it also can be specified in 'os/arch/variant' format for the resulting image. Eg, linux/arm/v7. The 'arch' and 'variant' parts are optional.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_build_arg -- Secret build argument in '--secret-build-arg name[=value]' format. Multiples supported by passing '--secret-build-arg name[=value]' multiple times.
    - target -- The name of the target build stage.
    - timeout -- The timeout in seconds.
    '''
    return _call_az("az acr build", locals())


def run(registry, agent_pool=None, auth_mode=None, file=None, log_template=None, no_format=None, no_logs=None, no_wait=None, platform=None, resource_group=None, set=None, set_secret=None, timeout=None, values=None):
    '''
    Queues a quick run providing streamed logs for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - agent_pool -- The name of the agent pool.
    - auth_mode -- Auth mode of the source registry.
    - file -- The task template/definition file path relative to the source context. It can be '-' to pipe a file from the standard input.
    - log_template -- The repository and tag template for run log artifact using the format: 'log/repo:tag' (e.g., 'acr/logs:{{.Run.ID}}'). Only applicable to CMK enabled registry.
    - no_format -- Indicates whether the logs should be displayed in raw format
    - no_logs -- Do not show logs after successfully queuing the build.
    - no_wait -- Do not wait for the run to complete and return immediately after queuing the run.
    - platform -- The platform where build/task is run, Eg, 'windows' and 'linux'. When it's used in build commands, it also can be specified in 'os/arch/variant' format for the resulting image. Eg, linux/arm/v7. The 'arch' and 'variant' parts are optional.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - set -- Value in 'name[=value]' format. Multiples supported by passing --set multiple times.
    - set_secret -- Secret value in '--set name[=value]' format. Multiples supported by passing --set multiple times.
    - timeout -- The timeout in seconds.
    - values -- The task values file path relative to the source context.
    '''
    return _call_az("az acr run", locals())


def check_health(ignore_errors=None, name=None, vnet=None, yes=None):
    '''
    Gets health information on the environment and optionally a target registry.

    Optional Parameters:
    - ignore_errors -- Provide all health checks, even if errors are found
    - name -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - vnet -- Virtual network ID so to run this command inside a VNET to verify the DNS routing to private endpoints
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr check-health", locals())




from ..... pyaz_utils import _call_az

def show(account_name, policy_id, rule_id, resource_group=None):
    '''
    Show the properties of specified rule in Object Replication Service Policy.

    Required Parameters:
    - account_name -- The storage account name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.
    - rule_id -- Rule Id is auto-generated for each new rule on destination account. It is required for put policy on source account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy rule show", locals())


def list(account_name, policy_id, resource_group=None):
    '''
    List all the rules in the specified Object Replication Service Policy.

    Required Parameters:
    - account_name -- The storage account name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy rule list", locals())


def add(account_name, destination_container, policy_id, source_container, min_creation_time=None, prefix_match=None, resource_group=None):
    '''
    Add rule to the specified Object Replication Service Policy.

    Required Parameters:
    - account_name -- The storage account name.
    - destination_container -- The destination storage container name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.
    - source_container -- The source storage container name.

    Optional Parameters:
    - min_creation_time -- Blobs created after the time will be replicated to the destination. It must be in datetime format 'yyyy-MM-ddTHH:mm:ssZ'. Example: 2020-02-19T16:05:00Z
    - prefix_match -- Optional. Filter the results to replicate only blobs whose names begin with the specified prefix.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy rule add", locals())


def update(account_name, policy_id, rule_id, destination_container=None, min_creation_time=None, prefix_match=None, resource_group=None, source_container=None):
    '''
    Update rule properties to Object Replication Service Policy.

    Required Parameters:
    - account_name -- The storage account name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.
    - rule_id -- Rule Id is auto-generated for each new rule on destination account. It is required for put policy on source account.

    Optional Parameters:
    - destination_container -- The destination storage container name.
    - min_creation_time -- Blobs created after the time will be replicated to the destination. It must be in datetime format 'yyyy-MM-ddTHH:mm:ssZ'. Example: 2020-02-19T16:05:00Z
    - prefix_match -- Optional. Filter the results to replicate only blobs whose names begin with the specified prefix.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source_container -- The source storage container name.
    '''
    return _call_az("az storage account or-policy rule update", locals())


def remove(account_name, policy_id, rule_id, resource_group=None):
    '''
    Remove the specified rule from the specified Object Replication Service Policy.

    Required Parameters:
    - account_name -- The storage account name.
    - policy_id -- The ID of object replication policy or "default" if the policy ID is unknown. Policy Id will be auto-generated when setting on destination account. Required when setting on source account.
    - rule_id -- Rule Id is auto-generated for each new rule on destination account. It is required for put policy on source account.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account or-policy rule remove", locals())

